@@ -18,7 +18,7 @@ WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
-from gurobipy import GRB, Model, quicksum, multidict, tuplelist
+import gurobipy # Note eclipse has problems importing quicksum so we dont import selectively
 from sqlalchemy.types import Text, Float
 from sqlalchemy.schema import Column, ForeignKeyConstraint, UniqueConstraint
 from sqlalchemy.orm import relationship
@@ -36,7 +36,9 @@ class Commodity(DataSetMixin):
     def __init__(self, name):
         self.name = name
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
 
 
 class Node(DataSetMixin):
@@ -44,7 +46,9 @@ class Node(DataSetMixin):
     latitude = Column(Float, nullable=False)
     longitude = Column(Float, nullable=False)
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
 
 
 class Arc(DataSetMixin):
@@ -56,11 +60,13 @@ class Arc(DataSetMixin):
     orig_node = relationship(Node, primaryjoin="and_(Arc.data_set_id==Node.data_set_id, Arc.orig_name==Node.name)")
     dest_node = relationship(Node, primaryjoin="and_(Arc.data_set_id==Node.data_set_id, Arc.dest_name==Node.name)")
 
-    __table_args__ = (
-        UniqueConstraint('data_set_id', 'orig_name', 'dest_name'),
-        ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')        
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            UniqueConstraint('data_set_id', 'orig_name', 'dest_name'),
+            ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')        
+        )
 
 
 class Cost(DataSetMixin):
@@ -74,13 +80,15 @@ class Cost(DataSetMixin):
     dest_node = relationship(Node, primaryjoin="and_(Cost.data_set_id==Node.data_set_id, Cost.dest_name==Node.name)")
     commodity = relationship(Commodity)
 
-    __table_args__ = (
-        UniqueConstraint('data_set_id', 'orig_name', 'dest_name', 'commod_name'),
-        ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['orig_name', 'dest_name', 'data_set_id'], ['arc.orig_name', 'arc.dest_name', 'arc.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            UniqueConstraint('data_set_id', 'orig_name', 'dest_name', 'commod_name'),
+            ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['orig_name', 'dest_name', 'data_set_id'], ['arc.orig_name', 'arc.dest_name', 'arc.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+        )
 
 
 class Inflow(DataSetMixin):
@@ -88,11 +96,13 @@ class Inflow(DataSetMixin):
     node_name = Column(Text, nullable=False)
     flow = Column(Float, nullable=False)
 
-    __table_args__ = (
-        UniqueConstraint('data_set_id', 'commod_name', 'node_name'),
-        ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['node_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            UniqueConstraint('data_set_id', 'commod_name', 'node_name'),
+            ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['node_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE')
+        )
 
 
 class NetworkFlow(DataSetMixin):
@@ -106,13 +116,15 @@ class NetworkFlow(DataSetMixin):
     dest_node = relationship(Node, primaryjoin="and_(NetworkFlow.data_set_id==Node.data_set_id, NetworkFlow.dest_name==Node.name)")
     commodity = relationship(Commodity)
 
-    __table_args__ = (
-        UniqueConstraint('data_set_id', 'orig_name', 'dest_name', 'commod_name'),
-        ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-        ForeignKeyConstraint(['orig_name', 'dest_name', 'data_set_id'], ['arc.orig_name', 'arc.dest_name', 'arc.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
-    )
+    @classmethod
+    def get_table_args(cls):
+        return (
+            UniqueConstraint('data_set_id', 'orig_name', 'dest_name', 'commod_name'),
+            ForeignKeyConstraint(['orig_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['dest_name', 'data_set_id'], ['node.name', 'node.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['commod_name', 'data_set_id'], ['commodity.name', 'commodity.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+            ForeignKeyConstraint(['orig_name', 'dest_name', 'data_set_id'], ['arc.orig_name', 'arc.dest_name', 'arc.data_set_id'], ondelete='CASCADE', onupdate='CASCADE'),
+        )
     
     
 class MapNodeInput(KMLMap):
@@ -261,13 +273,13 @@ class ExecuteSolverFunction(ExecuteFunction):
 
         commodities = [h.name for h in data_set.query(Commodity).all()]
         nodes = [n.name for n in data_set.query(Node).all()]
-        arcs, capacity = multidict(dict([((a.orig_name, a.dest_name), a.capacity) for a in data_set.query(Arc).all()]))
-        arcs = tuplelist(arcs)
+        arcs, capacity = gurobipy.multidict(dict([((a.orig_name, a.dest_name), a.capacity) for a in data_set.query(Arc).all()]))
+        arcs = gurobipy.tuplelist(arcs)
         cost = dict([((c.commod_name, c.orig_name, c.dest_name), c.cost) for c in data_set.query(Cost).all()])
         inflow = dict([((i.commod_name, i.node_name), i.flow) for i in data_set.query(Inflow).all()])
 
         # Create optimization model
-        m = Model('netflow')
+        m = gurobipy.Model('netflow')
         
         # Create variables
         flow = {}
@@ -279,16 +291,16 @@ class ExecuteSolverFunction(ExecuteFunction):
         
         # Arc capacity constraints
         for i,j in arcs:
-            m.addConstr(quicksum(flow[h,i,j] for h in commodities) <= capacity[i,j],
+            m.addConstr(gurobipy.quicksum(flow[h,i,j] for h in commodities) <= capacity[i,j],
                         'cap_%s_%s' % (i, j))
         
         # NetworkFlow conservation constraints
         for h in commodities:
             for j in nodes:
                 m.addConstr(
-                  quicksum(flow[h,i,j] for i,j in arcs.select('*',j)) +
+                  gurobipy.quicksum(flow[h,i,j] for i,j in arcs.select('*',j)) +
                       inflow[h,j] ==
-                  quicksum(flow[h,j,k] for j,k in arcs.select(j,'*')),
+                  gurobipy.quicksum(flow[h,j,k] for j,k in arcs.select(j,'*')),
                            'node_%s_%s' % (h, j))
         
         
@@ -299,7 +311,7 @@ class ExecuteSolverFunction(ExecuteFunction):
         # Print solution
         data_set.query(NetworkFlow).delete()
         
-        if m.status == GRB.status.OPTIMAL:
+        if m.status == gurobipy.GRB.status.OPTIMAL:
             solution = m.getAttr('x', flow)
             for h in commodities:
                 for i,j in arcs:
